@@ -246,6 +246,12 @@ class BrazilRioDeJaneiroTest(BrazilTest):
         # Dia de Nossa Senhora da Conceição
         self.assertIn(date(2017, 12, 8), holidays)
 
+    def test_carnaval_label(self):
+        holidays = self.cal.holidays(2017)
+        holidays_dict = dict(holidays)
+        label_carnaval = holidays_dict[date(2017, 2, 28)]
+        self.assertEqual(label_carnaval, "Carnaval")
+
 
 class BrazilRioGrandeDoNorteTest(BrazilTest):
     cal_class = BrazilRioGrandeDoNorte
@@ -338,6 +344,12 @@ class SaoPauloCityTest(SaoPauloStateTest):
             "Sexta-feira da Paixão",
         )
 
+    def test_carnaval_label(self):
+        holidays = self.cal.holidays(2013)
+        holidays_dict = dict(holidays)
+        label_carnaval = holidays_dict[date(2013, 2, 12)]
+        self.assertEqual(label_carnaval, "Carnaval")
+
 
 class BrazilSergipeTest(BrazilTest):
     cal_class = BrazilSergipe
@@ -481,6 +493,12 @@ class BrazilSerraCityTest(BrazilEspiritoSantoTest):
             "Paixão do Cristo",
         )
 
+    def test_carnaval_label(self):
+        holidays = self.cal.holidays(2017)
+        holidays_dict = dict(holidays)
+        label_carnaval = holidays_dict[date(2017, 2, 28)]
+        self.assertEqual(label_carnaval, "Carnaval")
+
 
 class BrazilRioBrancoCityTest(BrazilAcreTest):
     """
@@ -899,6 +917,12 @@ class BrazilBankCalendarTest(BrazilTest):
         working_day = self.cal.find_following_working_day(already_working_day)
         self.assertEquals(working_day, date(2017, 7, 25))
 
+    def test_carnaval_label(self):
+        holidays = self.cal.holidays(2017)
+        holidays_dict = dict(holidays)
+        label_carnaval = holidays_dict[date(2017, 2, 28)]
+        self.assertEqual(label_carnaval, "Tuesday carnaval")
+
 
 class TestIBGERegister(TestCase):
 
